## Some coding tests
- pytest (setup.cfg)
- pytest-cov (setup.cfg)
- pytest-mock

## Keywords
- Fixture (share data across test cases)
- Unit Test (test for indepedent component)
- Mock Test (test for depedent component)
- Parametrizing (various test cases for same component)
- Integration Test (end-to-end)


### References
1. https://blogs.sap.com/2022/02/16/how-to-write-independent-unit-test-with-pytest-and-mock-techniques/